<!--
 * @Description: 二级区县大屏工作部署模块
 * @Author: @liulin
 * @Date: 2023-04-07 14:33:42
 * @LastEditors: Do not edit
 * @LastEditTime: 2023-04-10 18:58:14
-->
<template>
    <div class="dialog-table-container">
        <el-table
            :element-loading-background="loadingColor"
            v-loading="loading"
            height="65vh"
            align="center"
            :data="tableData"
            class="dialog_table"
            :cell-style="{'text-align': 'center'}"
            :header-cell-style="{'text-align': 'center'}"
        >
            <el-table-column
                type="index"
                label="序号"
                width="60"
            ></el-table-column>
            <el-table-column prop="title" label="标题" align="left">
                <template v-slot="{row}">
                    <el-link
                        type="primary"
                        @click="openSubDialog('contentDialog', '', row)"
                        >{{ row.title }}</el-link
                    >
                </template>
            </el-table-column>
            <!-- <el-table-column prop="createOrgName" label="责任单位" width="200">
      </el-table-column> -->
            <!-- <el-table-column prop="drafter" label="撰稿人" width="100">
      </el-table-column> -->
            <el-table-column prop="excellent" label="优秀程度" width="220">
                <template v-slot="{row}">
                    <span v-if="row.excellent == 0">一般</span>
                    <span v-if="row.excellent == 1">优秀 </span>
                </template>
            </el-table-column>
            <!-- <el-table-column
        prop="endTime"
        label="有效日期"
        width="120"
      ></el-table-column> -->
        </el-table>

        <!-- 分页 -->
        <Pagenation
            @size-change="handleSizeChange"
            @currentChange="handleCurrentChange"
            :pageResult="pageResult"
        />

        <!-- 弹层 -->
        <EasyDialog
            v-model="showEasy"
            :width="dialogOption.width"
            :title="dialogOption.dialogTitle"
        >
            <component
                v-bind:is="currentTabComponent"
                :tableOptions="tableOptions_"
            ></component>
        </EasyDialog>
    </div>
</template>

<script>
import req from '@/request.js'
const portal = window.context.portal
import utils from '@/utils.js'
import EasyDialog from '@/views/BigScreen/components/easy-dialog/index.vue'
import dialogComponents from '@/views/BigScreen/js/district_reform_sub_dialog_component.js'
import dialogConfig from '@/views/BigScreen/js/DistrictReformSubDialogConfig.js'
import Pagenation from '@/views/BigScreen/components/innerTables/pagenation.vue'
export default {
    name: 'WorkDeployment',
    components: {
        EasyDialog,
        Pagenation,
        ...dialogComponents,
    },
    props: {
        tableOptions: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            loading: false,
            loadingColor: 'rgba(6, 46, 106, 0.4)',
            tableData: [],
            dialogOption: {
                dialogTitle: '',
                width: '50%',
            },
            showEasy: false,
            tableOptions_: {},
            currentTabComponent: null,
            pageResult: {
                page: 1,
                pageSize: 20,
            },
            params: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    showTotal: true,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'n.OPERATE_TYPE_',
                        relation: 'AND',
                        value: '2',
                    },
                    {
                        group: 'main',
                        operation: 'IN',
                        parentGroup: '',
                        property: 'n.EXCELLENT_',
                        relation: 'AND',
                        value: [2, 3],
                    },
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'o.CODE_',
                        relation: 'AND',
                        value: '',
                    },
                ],
            },
        }
    },
    mounted() {
        this.querysParams = this.$route.query
        let {code} = this.querysParams
        // let {quarter, year} = this.tableOptions
        this.loadData(code)
    },
    methods: {
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        // 改革品牌榜
        loadData(unitCode) {
            this.loading = true
            this.params.querys[2].value = unitCode
            const api = `/fill/bizWorkNews/v1/queryCode`
            req.post(portal + api, this.params)
                .then((res) => {
                    const data = (res && res.data) || []
                    this.tableData = data.rows
                    this.pageResult = {
                        page: data.page,
                        pageSize: data.pageSize,
                        total: data.total,
                    }
                    this.loading = false
                })
                .catch(() => {
                    this.loading = false
                })
        },
        // 打开弹层
        openSubDialog(componentName, type, column) {
            this.currentTabComponent = dialogConfig.dialogOption[componentName]
                .componentName
                ? dialogConfig.dialogOption[componentName].componentName
                : componentName // 动态组件名称
            if (column) {
                dialogConfig.dialogOption[componentName].option.dialogTitle =
                    column.title
                this.tableOptions_.id = column.id
            }
            this.tableOptions_ = {
                ...dialogConfig.dialogOption[componentName].dataOptions,
                ...this.tableOptions_,
                type,
            } //table的查询参数
            this.dialogOption = dialogConfig.dialogOption[componentName].option //弹窗配置参数
            this.showEasy = true
        },
        // 分页
        handleSizeChange(size) {
            this.params.size = size
            let {code} = this.querysParams
            this.loadData(code)
        },
        handleCurrentChange(current) {
            this.params.size = current
            let {code} = this.querysParams
            this.loadData(code)
        },
    },
}
</script>
<style lang="scss" scoped>
/deep/ .el-link span {
  font-size: 14px;
  color: #d7f1ff;
}
/deep/ .el-link:hover {
  span {
    color: #1481ef;
  }
}
.column-item-rotate {
  display: inline-block;
  transform: rotateX(180deg);
}

.cqlt-icon-arrow {
  font-size: 18px;
}

.column-trend-icon-1 {
  color: #59c06c;
  text-shadow: #59c06c 1px 0 12px;
}

.column-trend-icon-2 {
  color: #fe3b30;
  text-shadow: #fe3b30 1px 0 12px;
}
</style>
<style lang="scss">
@import '../majorProjects-components/table.scss';
</style>
